#
# spec file for package kubectl-switch
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubectl-switch
Version:        2.2.8
Release:        1.1
Summary:        Simple tool to help manage multiple kubeconfig files
License:        MIT
URL:            https://github.com/mirceanton/kubectl-switch
Source:         kubectl-switch-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.24

%description
kubectl-switch is a command-line tool for managing and switching between
multiple Kubernetes configuration files located in the same directory. It
simplifies the process of selecting a Kubernetes context from multiple
kubeconfig files and updating the active configuration or namespace.

Just dump all your kubeconfigs into a single dir and let kubectl-switch manage
them for you!

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build

%install
# Install the binary.
install -D -m 0755 %{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check
%{buildroot}/%{_bindir}/%{name} --help

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Mon Jun 23 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.2.8:
  * Bug Fixes
  - go: update k8s.io/client-go ( v0.33.1 → v0.33.2 ) (8cbb12d)
  * CI/CD
  - github-action: update mirceanton/action-semver-metadata (
    v1.0.1 → v1.0.3 ) (30c9319)
* Fri Jun 20 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.2.7:
  * Bug Fixes
  - go: update k8s.io/apimachinery ( v0.33.1 → v0.33.2 )
    (f24b64c)
  * CI/CD
  - github-action: update github/codeql-action ( v3.28.19 →
    v3.29.0 ) (da2b923)
  - github-action: update softprops/action-gh-release ( v2.3.0 →
    v2.3.2 ) (0f567f8)
  - github-action: update softprops/action-gh-release ( v2.2.2 →
    v2.3.0 ) (157c777)
  - github-action: update github/codeql-action ( v3.28.18 →
    v3.28.19 ) (5172aa0)
  - github-action: update aquasecurity/trivy-action ( 0.30.0 →
    0.31.0 ) (17a392b)
  - renovate: update inputs (91a5068)
  - github-action: pin mirceanton/action-semver-metadata action
    to 31be2c0 (#198) (3620fad)
  - github-action: update jdx/mise-action ( v2.2.2 → v2.2.3 )
    (018cc30)
  - update action-semver-metadata to version 1.0.1 (9a5d775)
  - release: use mirceanton/action-semver-metadata +
    softprops/action-gh-release (af554e3)
  - github-action: update jdx/mise-action ( c94f0bf → 13abe50 )
    (ed85c2d)
  * Chores
  - mise: update aqua:goreleaser/goreleaser ( 2.10.1 → 2.10.2 )
    (dae23bc)
  - mise: update aqua:goreleaser/goreleaser ( 2.10.0 → 2.10.1 )
    (a112477)
  - mise: update aqua:goreleaser/goreleaser ( 2.9.0 → 2.10.0 )
    (126e731)
  - mise: update go ( 1.24.3 → 1.24.4 ) (7858374)
  - mise: update go ( 1.24.2 → 1.24.3 ) (f45c11a)
  - mise: update config (45c2cd8)
  - mise: update renovate ( 40.18.0 → 40.25.0 ) (f9c428b)
  - mise: update renovate ( 40.17.0 → 40.18.0 ) (6194cfe)
* Fri May 23 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.2.6:
  * fix: update import path for kubeconfig package to include
    version suffix
  * chore(go): retract versions prior to v2.2.6
  * docs: update installation instructions and add Docker usage
    details
  * fix(go): add `/v2` suffix to module path for `go install`
  * build(container): use distroless base image instead of alpine
  * chore: update gitignore
  * chore(mise): update renovate ( 40.16.0 → 40.17.0 )
  * chore(mise): update renovate ( 40.15.0 → 40.16.0 )
  * chore(mise): update renovate ( 40.14.6 → 40.15.0 )
  * chore(mise): update renovate ( 40.14.5 → 40.14.6 )
  * chore(mise): update renovate ( 40.14.4 → 40.14.5 )
  * chore(mise): update renovate ( 40.14.3 → 40.14.4 )
  * chore(mise): update renovate ( 40.14.2 → 40.14.3 )
  * chore(mise): update renovate ( 40.14.1 → 40.14.2 )
  * chore(mise): update renovate ( 40.14.0 → 40.14.1 )
  * chore(mise): update renovate ( 40.13.1 → 40.14.0 )
  * chore(mise): update renovate ( 40.13.0 → 40.13.1 )
  * ci(github-action): update github/codeql-action ( v3.28.17 →
    v3.28.18 )
  * chore(mise): update renovate ( 40.12.3 → 40.13.0 )
* Wed May 21 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubectl-switch: simple tool to help manage multiple
  kubeconfig files
